const MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER;
const MIN_SAFE_INTEGER = Number.MIN_SAFE_INTEGER;
/**
 * Validates the range.
 * @throws {RangeError} If the min is out of range, the max is out of range,
 * or the min is greater than the max.
 * @param {Partial<Range>} range The range to validate.
 * @param {Partial<Range>} bounds Upper and lower inclusive bounds for the range.
 * @returns {Range} The validated range.
 * @example
 * // returns { min: -5, max: 5 }
 * // validateRange({ max: 5 }, { min: -5, max: 25 })
 * @example
 * // throws RangeError since range is out of bounds
 * // validateRange({ min: -5, max: 5 }, { min: 0, max: 5 })
 */
export const validateRange = (range, bounds) => {
    // Initialize min, max, lowerBound, and upperBound from options
    const lowerBound = typeof (bounds === null || bounds === void 0 ? void 0 : bounds.min) === "undefined" ? MIN_SAFE_INTEGER : bounds.min;
    const upperBound = typeof (bounds === null || bounds === void 0 ? void 0 : bounds.max) === "undefined" ? MAX_SAFE_INTEGER : bounds.max;
    const min = typeof (range === null || range === void 0 ? void 0 : range.min) === "undefined" ? lowerBound : range.min;
    const max = typeof (range === null || range === void 0 ? void 0 : range.max) === "undefined" ? upperBound : range.max;
    // Validate range
    if (min > max || lowerBound > upperBound)
        throw new RangeError("Chance: Min cannot be greater than the max.");
    if (min < lowerBound)
        throw new RangeError(`Chance: Min cannot be less than ${printBound(lowerBound)}.`);
    if (min > upperBound)
        throw new RangeError(`Chance: Min cannot be greater than ${printBound(upperBound)}.`);
    if (max < lowerBound)
        throw new RangeError(`Chance: Max cannot be less than ${printBound(lowerBound)}.`);
    if (max > upperBound)
        throw new RangeError(`Chance: Max cannot be greater than ${printBound(upperBound)}.`);
    // Return validated min and max
    return {
        min,
        max,
    };
};
const printBound = (bound) => {
    if (bound === MAX_SAFE_INTEGER) {
        ("the largest safe integer allowed in JavaScript (Number.MAX_SAFE_INTEGER)");
    }
    if (bound === MIN_SAFE_INTEGER) {
        ("the smallest safe integer allowed in JavaScript (Number.MIN_SAFE_INTEGER)");
    }
    return bound.toString();
};
